# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: robot_test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import messages_pb2 as messages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='robot_test.proto',
  package='robotc',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10robot_test.proto\x12\x06robotc\x1a\x0emessages.proto\"\x07\n\x05\x45mpty\"\'\n\x06Result\x12\n\n\x02ok\x18\x01 \x01(\x05\x12\x11\n\ttestError\x18\x02 \x01(\x05\"\x16\n\x06Joints\x12\x0c\n\x04pose\x18\x01 \x03(\x01\"\x1b\n\x0eReducerRequest\x12\t\n\x01v\x18\x01 \x01(\x01\";\n\rReducerResult\x12\x0f\n\x07voltage\x18\x01 \x01(\x01\x12\t\n\x01v\x18\x02 \x01(\x01\x12\x0e\n\x06torque\x18\x03 \x01(\x01\")\n\x10JointStudyResult\x12\x15\n\rmotor_encoder\x18\x01 \x01(\r\"\"\n\x0cJointRequest\x12\x12\n\njoint_type\x18\x01 \x01(\r\"\xf5\x01\n\x0bJointResult\x12\x10\n\x08\x62\x61\x63klash\x18\x01 \x01(\x01\x12\x17\n\x0fpos_stable_time\x18\x02 \x01(\x01\x12\x14\n\x0cpos_overshot\x18\x03 \x01(\x01\x12\x13\n\x0btemperature\x18\x04 \x01(\x01\x12\x0f\n\x07\x63urrent\x18\x05 \x01(\x01\x12\x0f\n\x07voltage\x18\x06 \x01(\x01\x12\t\n\x01v\x18\x07 \x01(\x01\x12\x0e\n\x06torque\x18\x08 \x01(\x01\x12\x15\n\rmotor_encoder\x18\t \x01(\r\x12\x14\n\x0cjoint_torque\x18\n \x01(\x01\x12\x13\n\x0breducer_eff\x18\x0b \x01(\x01\x12\x11\n\tmotor_eff\x18\x0c \x01(\x01\"@\n\x0e\x43ommandRequest\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0f\n\x07value_i\x18\x02 \x01(\x05\x12\x0f\n\x07value_f\x18\x03 \x01(\x01\"\x1d\n\rCommandResult\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\"\x8b\x01\n\tMovePoint\x12\x15\n\rjoint_pose_to\x18\x01 \x03(\x01\x12\x1b\n\x13pose_is_joint_angle\x18\x02 \x01(\x08\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x03 \x01(\x01\x12\x10\n\x08velocity\x18\x04 \x01(\x01\x12\x0c\n\x04time\x18\x05 \x01(\x01\x12\x14\n\x0c\x62lend_radius\x18\x06 \x01(\x01\"\xd2\x01\n\x0cRunInRequest\x12\x1f\n\x04path\x18\x01 \x03(\x0b\x32\x11.robotc.MovePoint\x12\x19\n\x11\x65quivalent_radius\x18\x02 \x01(\x01\x12\x1a\n\x12threshold_distance\x18\x03 \x01(\x01\x12\x1c\n\x14position_stable_time\x18\x04 \x01(\x01\x12\x1a\n\x12position_overshoot\x18\x05 \x01(\x01\x12\x18\n\x10pose_stable_time\x18\x06 \x01(\x01\x12\x16\n\x0epose_overshoot\x18\x07 \x01(\x01\"\x98\x01\n\x0eRunInJointInfo\x12\x14\n\x0cmin_velocity\x18\x01 \x01(\x01\x12\x14\n\x0cmax_velocity\x18\x02 \x01(\x01\x12\x13\n\x0bmin_voltage\x18\x03 \x01(\x01\x12\x13\n\x0bmax_voltage\x18\x04 \x01(\x01\x12\x17\n\x0fmin_temperature\x18\x05 \x01(\x01\x12\x17\n\x0fmax_temperature\x18\x06 \x01(\x01\"9\n\x0fRunInPathResult\x12&\n\x06joints\x18\x01 \x03(\x0b\x32\x16.robotc.RunInJointInfo\"\xbe\x01\n\x0bRunInResult\x12\n\n\x02ok\x18\x01 \x01(\x08\x12%\n\x04path\x18\x02 \x03(\x0b\x32\x17.robotc.RunInPathResult\x12\x1c\n\x14position_stable_time\x18\x04 \x01(\x01\x12\x1a\n\x12position_overshoot\x18\x05 \x01(\x01\x12\x18\n\x10pose_stable_time\x18\x06 \x01(\x01\x12\x16\n\x0epose_overshoot\x18\x07 \x01(\x01\x12\x10\n\x08\x66ilename\x18\x08 \x01(\t\"\x17\n\tDeviceIds\x12\n\n\x02id\x18\x01 \x03(\r\"\x1d\n\x0c\x44\x65viceValues\x12\r\n\x05value\x18\x01 \x03(\x01\"!\n\x12ProductTestRequest\x12\x0b\n\x03\x63md\x18\x01 \x01(\r\"7\n\x11ProductTestResult\x12\x0f\n\x07testRes\x18\x01 \x01(\r\x12\x11\n\ttestError\x18\x02 \x01(\r\"+\n\x0fInitRobotResult\x12\x0b\n\x03ret\x18\x01 \x01(\x05\x12\x0b\n\x03\x63up\x18\x02 \x01(\t\"#\n\rWriteSnResult\x12\x12\n\nwriteSnRes\x18\x01 \x01(\x05\"$\n\x11\x44\x65viceTypeRequest\x12\x0f\n\x07\x64\x65vType\x18\x01 \x01(\x05\"*\n\x0c\x44\x65\x63imalInput\x12\x0b\n\x03pin\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05\"|\n\x0eMoveDetectPath\x12\x1f\n\x04path\x18\x01 \x01(\x0b\x32\x11.robotc.MovePoint\x12$\n\x06moving\x18\x02 \x03(\x0b\x32\x14.robotc.DecimalInput\x12#\n\x05\x63ross\x18\x03 \x03(\x0b\x32\x14.robotc.DecimalInput\"8\n\x11MoveDetectRequest\x12#\n\x03req\x18\x01 \x03(\x0b\x32\x16.robotc.MoveDetectPath\"U\n\x10MoveDetectResult\x12\n\n\x02ok\x18\x01 \x01(\x08\x12#\n\x03res\x18\x02 \x03(\x0b\x32\x16.robotc.MoveDetectPath\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t2\xb1\x06\n\tRobotTest\x12\x30\n\x0fInitReducerTest\x12\r.robotc.Empty\x1a\x0e.robotc.Result\x12<\n\x0bReducerTest\x12\x16.robotc.ReducerRequest\x1a\x15.robotc.ReducerResult\x12.\n\rInitJointTest\x12\r.robotc.Empty\x1a\x0e.robotc.Result\x12\x35\n\nJointStudy\x12\r.robotc.Empty\x1a\x18.robotc.JointStudyResult\x12\x36\n\tJointTest\x12\x14.robotc.JointRequest\x1a\x13.robotc.JointResult\x12<\n\x0bTestCommand\x12\x16.robotc.CommandRequest\x1a\x15.robotc.CommandResult\x12\x36\n\tRunInTest\x12\x14.robotc.RunInRequest\x1a\x13.robotc.RunInResult\x12\x45\n\x0eMoveDetectTest\x12\x19.robotc.MoveDetectRequest\x1a\x18.robotc.MoveDetectResult\x12;\n\x10GetDialIndicator\x12\x11.robotc.DeviceIds\x1a\x14.robotc.DeviceValues\x12I\n\x10StartProductTest\x12\x1a.robotc.ProductTestRequest\x1a\x19.robotc.ProductTestResult\x12(\n\x07\x42oxTest\x12\r.robotc.Empty\x1a\x0e.robotc.Result\x12\x37\n\tInitRobot\x12\x11.robotc.RobotInfo\x1a\x17.robotc.InitRobotResult\x12\x34\n\x07WriteSn\x12\x12.robotc.DeviceInfo\x1a\x15.robotc.WriteSnResult\x12\x37\n\x06ReadSn\x12\x19.robotc.DeviceTypeRequest\x1a\x12.robotc.DeviceInfob\x06proto3'
  ,
  dependencies=[messages__pb2.DESCRIPTOR,])




_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='robotc.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=51,
)


_RESULT = _descriptor.Descriptor(
  name='Result',
  full_name='robotc.Result',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='robotc.Result.ok', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testError', full_name='robotc.Result.testError', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=92,
)


_JOINTS = _descriptor.Descriptor(
  name='Joints',
  full_name='robotc.Joints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='robotc.Joints.pose', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=116,
)


_REDUCERREQUEST = _descriptor.Descriptor(
  name='ReducerRequest',
  full_name='robotc.ReducerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='v', full_name='robotc.ReducerRequest.v', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=145,
)


_REDUCERRESULT = _descriptor.Descriptor(
  name='ReducerResult',
  full_name='robotc.ReducerResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voltage', full_name='robotc.ReducerResult.voltage', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v', full_name='robotc.ReducerResult.v', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='torque', full_name='robotc.ReducerResult.torque', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=206,
)


_JOINTSTUDYRESULT = _descriptor.Descriptor(
  name='JointStudyResult',
  full_name='robotc.JointStudyResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='motor_encoder', full_name='robotc.JointStudyResult.motor_encoder', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=249,
)


_JOINTREQUEST = _descriptor.Descriptor(
  name='JointRequest',
  full_name='robotc.JointRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joint_type', full_name='robotc.JointRequest.joint_type', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=285,
)


_JOINTRESULT = _descriptor.Descriptor(
  name='JointResult',
  full_name='robotc.JointResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backlash', full_name='robotc.JointResult.backlash', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pos_stable_time', full_name='robotc.JointResult.pos_stable_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pos_overshot', full_name='robotc.JointResult.pos_overshot', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='robotc.JointResult.temperature', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current', full_name='robotc.JointResult.current', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voltage', full_name='robotc.JointResult.voltage', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v', full_name='robotc.JointResult.v', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='torque', full_name='robotc.JointResult.torque', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motor_encoder', full_name='robotc.JointResult.motor_encoder', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joint_torque', full_name='robotc.JointResult.joint_torque', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reducer_eff', full_name='robotc.JointResult.reducer_eff', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='motor_eff', full_name='robotc.JointResult.motor_eff', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=533,
)


_COMMANDREQUEST = _descriptor.Descriptor(
  name='CommandRequest',
  full_name='robotc.CommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='robotc.CommandRequest.type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_i', full_name='robotc.CommandRequest.value_i', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_f', full_name='robotc.CommandRequest.value_f', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=535,
  serialized_end=599,
)


_COMMANDRESULT = _descriptor.Descriptor(
  name='CommandResult',
  full_name='robotc.CommandResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='robotc.CommandResult.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=630,
)


_MOVEPOINT = _descriptor.Descriptor(
  name='MovePoint',
  full_name='robotc.MovePoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joint_pose_to', full_name='robotc.MovePoint.joint_pose_to', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_is_joint_angle', full_name='robotc.MovePoint.pose_is_joint_angle', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acceleration', full_name='robotc.MovePoint.acceleration', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='robotc.MovePoint.velocity', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='robotc.MovePoint.time', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='blend_radius', full_name='robotc.MovePoint.blend_radius', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=772,
)


_RUNINREQUEST = _descriptor.Descriptor(
  name='RunInRequest',
  full_name='robotc.RunInRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='robotc.RunInRequest.path', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='equivalent_radius', full_name='robotc.RunInRequest.equivalent_radius', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold_distance', full_name='robotc.RunInRequest.threshold_distance', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_stable_time', full_name='robotc.RunInRequest.position_stable_time', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_overshoot', full_name='robotc.RunInRequest.position_overshoot', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_stable_time', full_name='robotc.RunInRequest.pose_stable_time', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_overshoot', full_name='robotc.RunInRequest.pose_overshoot', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=985,
)


_RUNINJOINTINFO = _descriptor.Descriptor(
  name='RunInJointInfo',
  full_name='robotc.RunInJointInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_velocity', full_name='robotc.RunInJointInfo.min_velocity', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_velocity', full_name='robotc.RunInJointInfo.max_velocity', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_voltage', full_name='robotc.RunInJointInfo.min_voltage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_voltage', full_name='robotc.RunInJointInfo.max_voltage', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_temperature', full_name='robotc.RunInJointInfo.min_temperature', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_temperature', full_name='robotc.RunInJointInfo.max_temperature', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=988,
  serialized_end=1140,
)


_RUNINPATHRESULT = _descriptor.Descriptor(
  name='RunInPathResult',
  full_name='robotc.RunInPathResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='joints', full_name='robotc.RunInPathResult.joints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1142,
  serialized_end=1199,
)


_RUNINRESULT = _descriptor.Descriptor(
  name='RunInResult',
  full_name='robotc.RunInResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='robotc.RunInResult.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='robotc.RunInResult.path', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_stable_time', full_name='robotc.RunInResult.position_stable_time', index=2,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_overshoot', full_name='robotc.RunInResult.position_overshoot', index=3,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_stable_time', full_name='robotc.RunInResult.pose_stable_time', index=4,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_overshoot', full_name='robotc.RunInResult.pose_overshoot', index=5,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename', full_name='robotc.RunInResult.filename', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1202,
  serialized_end=1392,
)


_DEVICEIDS = _descriptor.Descriptor(
  name='DeviceIds',
  full_name='robotc.DeviceIds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='robotc.DeviceIds.id', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1394,
  serialized_end=1417,
)


_DEVICEVALUES = _descriptor.Descriptor(
  name='DeviceValues',
  full_name='robotc.DeviceValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.DeviceValues.value', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1419,
  serialized_end=1448,
)


_PRODUCTTESTREQUEST = _descriptor.Descriptor(
  name='ProductTestRequest',
  full_name='robotc.ProductTestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cmd', full_name='robotc.ProductTestRequest.cmd', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1450,
  serialized_end=1483,
)


_PRODUCTTESTRESULT = _descriptor.Descriptor(
  name='ProductTestResult',
  full_name='robotc.ProductTestResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='testRes', full_name='robotc.ProductTestResult.testRes', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testError', full_name='robotc.ProductTestResult.testError', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1485,
  serialized_end=1540,
)


_INITROBOTRESULT = _descriptor.Descriptor(
  name='InitRobotResult',
  full_name='robotc.InitRobotResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ret', full_name='robotc.InitRobotResult.ret', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cup', full_name='robotc.InitRobotResult.cup', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1542,
  serialized_end=1585,
)


_WRITESNRESULT = _descriptor.Descriptor(
  name='WriteSnResult',
  full_name='robotc.WriteSnResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='writeSnRes', full_name='robotc.WriteSnResult.writeSnRes', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1587,
  serialized_end=1622,
)


_DEVICETYPEREQUEST = _descriptor.Descriptor(
  name='DeviceTypeRequest',
  full_name='robotc.DeviceTypeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='devType', full_name='robotc.DeviceTypeRequest.devType', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1624,
  serialized_end=1660,
)


_DECIMALINPUT = _descriptor.Descriptor(
  name='DecimalInput',
  full_name='robotc.DecimalInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pin', full_name='robotc.DecimalInput.pin', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='robotc.DecimalInput.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1662,
  serialized_end=1704,
)


_MOVEDETECTPATH = _descriptor.Descriptor(
  name='MoveDetectPath',
  full_name='robotc.MoveDetectPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='robotc.MoveDetectPath.path', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='moving', full_name='robotc.MoveDetectPath.moving', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cross', full_name='robotc.MoveDetectPath.cross', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1706,
  serialized_end=1830,
)


_MOVEDETECTREQUEST = _descriptor.Descriptor(
  name='MoveDetectRequest',
  full_name='robotc.MoveDetectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req', full_name='robotc.MoveDetectRequest.req', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1832,
  serialized_end=1888,
)


_MOVEDETECTRESULT = _descriptor.Descriptor(
  name='MoveDetectResult',
  full_name='robotc.MoveDetectResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='robotc.MoveDetectResult.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='res', full_name='robotc.MoveDetectResult.res', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename', full_name='robotc.MoveDetectResult.filename', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1890,
  serialized_end=1975,
)

_RUNINREQUEST.fields_by_name['path'].message_type = _MOVEPOINT
_RUNINPATHRESULT.fields_by_name['joints'].message_type = _RUNINJOINTINFO
_RUNINRESULT.fields_by_name['path'].message_type = _RUNINPATHRESULT
_MOVEDETECTPATH.fields_by_name['path'].message_type = _MOVEPOINT
_MOVEDETECTPATH.fields_by_name['moving'].message_type = _DECIMALINPUT
_MOVEDETECTPATH.fields_by_name['cross'].message_type = _DECIMALINPUT
_MOVEDETECTREQUEST.fields_by_name['req'].message_type = _MOVEDETECTPATH
_MOVEDETECTRESULT.fields_by_name['res'].message_type = _MOVEDETECTPATH
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['Result'] = _RESULT
DESCRIPTOR.message_types_by_name['Joints'] = _JOINTS
DESCRIPTOR.message_types_by_name['ReducerRequest'] = _REDUCERREQUEST
DESCRIPTOR.message_types_by_name['ReducerResult'] = _REDUCERRESULT
DESCRIPTOR.message_types_by_name['JointStudyResult'] = _JOINTSTUDYRESULT
DESCRIPTOR.message_types_by_name['JointRequest'] = _JOINTREQUEST
DESCRIPTOR.message_types_by_name['JointResult'] = _JOINTRESULT
DESCRIPTOR.message_types_by_name['CommandRequest'] = _COMMANDREQUEST
DESCRIPTOR.message_types_by_name['CommandResult'] = _COMMANDRESULT
DESCRIPTOR.message_types_by_name['MovePoint'] = _MOVEPOINT
DESCRIPTOR.message_types_by_name['RunInRequest'] = _RUNINREQUEST
DESCRIPTOR.message_types_by_name['RunInJointInfo'] = _RUNINJOINTINFO
DESCRIPTOR.message_types_by_name['RunInPathResult'] = _RUNINPATHRESULT
DESCRIPTOR.message_types_by_name['RunInResult'] = _RUNINRESULT
DESCRIPTOR.message_types_by_name['DeviceIds'] = _DEVICEIDS
DESCRIPTOR.message_types_by_name['DeviceValues'] = _DEVICEVALUES
DESCRIPTOR.message_types_by_name['ProductTestRequest'] = _PRODUCTTESTREQUEST
DESCRIPTOR.message_types_by_name['ProductTestResult'] = _PRODUCTTESTRESULT
DESCRIPTOR.message_types_by_name['InitRobotResult'] = _INITROBOTRESULT
DESCRIPTOR.message_types_by_name['WriteSnResult'] = _WRITESNRESULT
DESCRIPTOR.message_types_by_name['DeviceTypeRequest'] = _DEVICETYPEREQUEST
DESCRIPTOR.message_types_by_name['DecimalInput'] = _DECIMALINPUT
DESCRIPTOR.message_types_by_name['MoveDetectPath'] = _MOVEDETECTPATH
DESCRIPTOR.message_types_by_name['MoveDetectRequest'] = _MOVEDETECTREQUEST
DESCRIPTOR.message_types_by_name['MoveDetectResult'] = _MOVEDETECTRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Empty)
  })
_sym_db.RegisterMessage(Empty)

Result = _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Result)
  })
_sym_db.RegisterMessage(Result)

Joints = _reflection.GeneratedProtocolMessageType('Joints', (_message.Message,), {
  'DESCRIPTOR' : _JOINTS,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.Joints)
  })
_sym_db.RegisterMessage(Joints)

ReducerRequest = _reflection.GeneratedProtocolMessageType('ReducerRequest', (_message.Message,), {
  'DESCRIPTOR' : _REDUCERREQUEST,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ReducerRequest)
  })
_sym_db.RegisterMessage(ReducerRequest)

ReducerResult = _reflection.GeneratedProtocolMessageType('ReducerResult', (_message.Message,), {
  'DESCRIPTOR' : _REDUCERRESULT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ReducerResult)
  })
_sym_db.RegisterMessage(ReducerResult)

JointStudyResult = _reflection.GeneratedProtocolMessageType('JointStudyResult', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSTUDYRESULT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JointStudyResult)
  })
_sym_db.RegisterMessage(JointStudyResult)

JointRequest = _reflection.GeneratedProtocolMessageType('JointRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOINTREQUEST,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JointRequest)
  })
_sym_db.RegisterMessage(JointRequest)

JointResult = _reflection.GeneratedProtocolMessageType('JointResult', (_message.Message,), {
  'DESCRIPTOR' : _JOINTRESULT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.JointResult)
  })
_sym_db.RegisterMessage(JointResult)

CommandRequest = _reflection.GeneratedProtocolMessageType('CommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDREQUEST,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.CommandRequest)
  })
_sym_db.RegisterMessage(CommandRequest)

CommandResult = _reflection.GeneratedProtocolMessageType('CommandResult', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDRESULT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.CommandResult)
  })
_sym_db.RegisterMessage(CommandResult)

MovePoint = _reflection.GeneratedProtocolMessageType('MovePoint', (_message.Message,), {
  'DESCRIPTOR' : _MOVEPOINT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.MovePoint)
  })
_sym_db.RegisterMessage(MovePoint)

RunInRequest = _reflection.GeneratedProtocolMessageType('RunInRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNINREQUEST,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RunInRequest)
  })
_sym_db.RegisterMessage(RunInRequest)

RunInJointInfo = _reflection.GeneratedProtocolMessageType('RunInJointInfo', (_message.Message,), {
  'DESCRIPTOR' : _RUNINJOINTINFO,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RunInJointInfo)
  })
_sym_db.RegisterMessage(RunInJointInfo)

RunInPathResult = _reflection.GeneratedProtocolMessageType('RunInPathResult', (_message.Message,), {
  'DESCRIPTOR' : _RUNINPATHRESULT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RunInPathResult)
  })
_sym_db.RegisterMessage(RunInPathResult)

RunInResult = _reflection.GeneratedProtocolMessageType('RunInResult', (_message.Message,), {
  'DESCRIPTOR' : _RUNINRESULT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.RunInResult)
  })
_sym_db.RegisterMessage(RunInResult)

DeviceIds = _reflection.GeneratedProtocolMessageType('DeviceIds', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIDS,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DeviceIds)
  })
_sym_db.RegisterMessage(DeviceIds)

DeviceValues = _reflection.GeneratedProtocolMessageType('DeviceValues', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEVALUES,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DeviceValues)
  })
_sym_db.RegisterMessage(DeviceValues)

ProductTestRequest = _reflection.GeneratedProtocolMessageType('ProductTestRequest', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTTESTREQUEST,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ProductTestRequest)
  })
_sym_db.RegisterMessage(ProductTestRequest)

ProductTestResult = _reflection.GeneratedProtocolMessageType('ProductTestResult', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTTESTRESULT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.ProductTestResult)
  })
_sym_db.RegisterMessage(ProductTestResult)

InitRobotResult = _reflection.GeneratedProtocolMessageType('InitRobotResult', (_message.Message,), {
  'DESCRIPTOR' : _INITROBOTRESULT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.InitRobotResult)
  })
_sym_db.RegisterMessage(InitRobotResult)

WriteSnResult = _reflection.GeneratedProtocolMessageType('WriteSnResult', (_message.Message,), {
  'DESCRIPTOR' : _WRITESNRESULT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.WriteSnResult)
  })
_sym_db.RegisterMessage(WriteSnResult)

DeviceTypeRequest = _reflection.GeneratedProtocolMessageType('DeviceTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICETYPEREQUEST,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DeviceTypeRequest)
  })
_sym_db.RegisterMessage(DeviceTypeRequest)

DecimalInput = _reflection.GeneratedProtocolMessageType('DecimalInput', (_message.Message,), {
  'DESCRIPTOR' : _DECIMALINPUT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.DecimalInput)
  })
_sym_db.RegisterMessage(DecimalInput)

MoveDetectPath = _reflection.GeneratedProtocolMessageType('MoveDetectPath', (_message.Message,), {
  'DESCRIPTOR' : _MOVEDETECTPATH,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.MoveDetectPath)
  })
_sym_db.RegisterMessage(MoveDetectPath)

MoveDetectRequest = _reflection.GeneratedProtocolMessageType('MoveDetectRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEDETECTREQUEST,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.MoveDetectRequest)
  })
_sym_db.RegisterMessage(MoveDetectRequest)

MoveDetectResult = _reflection.GeneratedProtocolMessageType('MoveDetectResult', (_message.Message,), {
  'DESCRIPTOR' : _MOVEDETECTRESULT,
  '__module__' : 'robot_test_pb2'
  # @@protoc_insertion_point(class_scope:robotc.MoveDetectResult)
  })
_sym_db.RegisterMessage(MoveDetectResult)



_ROBOTTEST = _descriptor.ServiceDescriptor(
  name='RobotTest',
  full_name='robotc.RobotTest',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1978,
  serialized_end=2795,
  methods=[
  _descriptor.MethodDescriptor(
    name='InitReducerTest',
    full_name='robotc.RobotTest.InitReducerTest',
    index=0,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_RESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReducerTest',
    full_name='robotc.RobotTest.ReducerTest',
    index=1,
    containing_service=None,
    input_type=_REDUCERREQUEST,
    output_type=_REDUCERRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InitJointTest',
    full_name='robotc.RobotTest.InitJointTest',
    index=2,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_RESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='JointStudy',
    full_name='robotc.RobotTest.JointStudy',
    index=3,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_JOINTSTUDYRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='JointTest',
    full_name='robotc.RobotTest.JointTest',
    index=4,
    containing_service=None,
    input_type=_JOINTREQUEST,
    output_type=_JOINTRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TestCommand',
    full_name='robotc.RobotTest.TestCommand',
    index=5,
    containing_service=None,
    input_type=_COMMANDREQUEST,
    output_type=_COMMANDRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunInTest',
    full_name='robotc.RobotTest.RunInTest',
    index=6,
    containing_service=None,
    input_type=_RUNINREQUEST,
    output_type=_RUNINRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MoveDetectTest',
    full_name='robotc.RobotTest.MoveDetectTest',
    index=7,
    containing_service=None,
    input_type=_MOVEDETECTREQUEST,
    output_type=_MOVEDETECTRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDialIndicator',
    full_name='robotc.RobotTest.GetDialIndicator',
    index=8,
    containing_service=None,
    input_type=_DEVICEIDS,
    output_type=_DEVICEVALUES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartProductTest',
    full_name='robotc.RobotTest.StartProductTest',
    index=9,
    containing_service=None,
    input_type=_PRODUCTTESTREQUEST,
    output_type=_PRODUCTTESTRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BoxTest',
    full_name='robotc.RobotTest.BoxTest',
    index=10,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_RESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InitRobot',
    full_name='robotc.RobotTest.InitRobot',
    index=11,
    containing_service=None,
    input_type=messages__pb2._ROBOTINFO,
    output_type=_INITROBOTRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WriteSn',
    full_name='robotc.RobotTest.WriteSn',
    index=12,
    containing_service=None,
    input_type=messages__pb2._DEVICEINFO,
    output_type=_WRITESNRESULT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadSn',
    full_name='robotc.RobotTest.ReadSn',
    index=13,
    containing_service=None,
    input_type=_DEVICETYPEREQUEST,
    output_type=messages__pb2._DEVICEINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ROBOTTEST)

DESCRIPTOR.services_by_name['RobotTest'] = _ROBOTTEST

# @@protoc_insertion_point(module_scope)
